# Generated by Django 3.2.9 on 2021-11-27 07:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('pinax_stripe', '0002_auto_20211126_1416'),
    ]

    operations = [
        migrations.RenameField(
            model_name='event',
            old_name='webhook_message',
            new_name='message',
        ),
        migrations.RemoveField(
            model_name='event',
            name='valid',
        ),
        migrations.RemoveField(
            model_name='event',
            name='validated_message',
        ),
    ]
